Class: MyApiClient::Params::Params
- Inherits:
-
Object
- Object
- MyApiClient::Params::Params
- Defined in:
- lib/my_api_client/params/params.rb
Overview
Description of Params
Instance Attribute Summary collapse
-
#request ⇒ Object
readonly
Returns the value of attribute request.
-
#response ⇒ Object
readonly
Returns the value of attribute response.
Instance Method Summary collapse
-
#initialize(request, response) ⇒ Params
constructor
Description of #initialize.
-
#inspect ⇒ String
Returns contents as string for to be readable for human.
-
#metadata ⇒ Hash
(also: #to_bugsnag)
Generate metadata for bugsnag.
Constructor Details
#initialize(request, response) ⇒ Params
Description of #initialize
13 14 15 16 |
# File 'lib/my_api_client/params/params.rb', line 13 def initialize(request, response) @request = request @response = response end |
Instance Attribute Details
#request ⇒ Object (readonly)
Returns the value of attribute request.
7 8 9 |
# File 'lib/my_api_client/params/params.rb', line 7 def request @request end |
#response ⇒ Object (readonly)
Returns the value of attribute response.
7 8 9 |
# File 'lib/my_api_client/params/params.rb', line 7 def response @response end |
Instance Method Details
#inspect ⇒ String
Returns contents as string for to be readable for human
31 32 33 |
# File 'lib/my_api_client/params/params.rb', line 31 def inspect { request:, response: }.inspect end |
#metadata ⇒ Hash Also known as: to_bugsnag
Generate metadata for bugsnag. It will integrate request and response params. Blank parameter will be omitted.
23 24 25 |
# File 'lib/my_api_client/params/params.rb', line 23 def .merge() end |